@@ -1,8 +1,8 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmIO.cc 9807 2017-12-06 15:33:25Z dwm $
+// @(#) $Id: DwmIO.cc 10858 2020-07-27 05:19:15Z dwm $
 //===========================================================================
-//  Copyright (c) Daniel W. McRobb 2004-2007
+//  Copyright (c) Daniel W. McRobb 2004-2007, 2013, 2017, 2020
 //  All rights reserved.
 //
 //  Redistribution and use in source and binary forms, with or without
@@ -57,7 +57,7 @@ extern "C" {
 #include "DwmIO.hh"
 #include "DwmPortability.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmIO.cc 9807 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.19/src/DwmIO.cc 10858 $");
 
 namespace Dwm {
 
@@ -416,16 +416,24 @@ namespace Dwm {
   //------------------------------------------------------------------------
   std::istream & IO::Read(std::istream & is, std::string & s)
   {
-    s = "";
+    s.clear();
     if (is) {
       uint32_t  len;
-      IO::Read(is,len);
+      IO::Read(is, len);
       if (len > 0) {
-        char  *buf = (char *)calloc(1,len);
-        if (buf) {
-          if (is.read(buf,len))
-            s.assign(buf,len);
-          free(buf);
+        try {
+          s.resize(len);
+          if (! is.read(s.data(), len)) {
+            s.clear();
+          }
+        }
+        catch (const std::exception & ex) {
+          Syslog(LOG_ERR, "Exception: %s", ex.what());
+          is.setstate(std::ios_base::failbit);
+        }
+        catch (...) {
+          Syslog(LOG_ERR, "Exception");
+          is.setstate(std::ios_base::failbit);
         }
       }
     }
@@ -768,26 +776,30 @@ namespace Dwm {
   //------------------------------------------------------------------------
   ssize_t IO::Read(int fd, std::string & s)
   {
-    s = "";
+    s.clear();
     ssize_t  rc = -1;
     if (fd >= 0) {
       uint32_t  len;
-      if (Read(fd,len) == sizeof(len)) {
+      if (Read(fd, len) == sizeof(len)) {
         rc = sizeof(len);
         if (len > 0) {
-          char  *buf = (char *)calloc(1, len);
-          if (buf) {
-            ssize_t  bytesRead = Read(fd, buf, len);
+          try {
+            s.resize(len);
+            ssize_t  bytesRead = Read(fd, s.data(), len);
             if (bytesRead == len) {
               rc += len;
-              s.assign(buf, len);
             }
             else {
+              s.clear();
               rc = -1;
             }
-            free(buf);
           }
-          else {
+          catch (const std::exception & ex) {
+            Syslog(LOG_ERR, "Exception: %s", ex.what());
+            rc = -1;
+          }
+          catch (...) {
+            Syslog(LOG_ERR, "Exception");
             rc = -1;
           }
         }
@@ -1140,23 +1152,32 @@ namespace Dwm {
   //------------------------------------------------------------------------
   size_t IO::Read(FILE * f, std::string & s)
   {
-    s = "";
+    s.clear();
     size_t  rc = 0;
     if (f) {
       uint32_t len;
-      if (Read(f,len) == sizeof(len)) {
+      if (Read(f, len) == sizeof(len)) {
         rc = sizeof(len);
         if (len > 0) {
-          char  *buf = (char *)calloc(1,len);
-          if (buf) {
-            if (fread((void *)buf,len,1,f) == 1) {
-              s.assign(buf,len);
+          try {
+            s.resize(len);
+            if (fread((void *)s.data(), len , 1, f) == 1) {
               rc += len;
             }
             else {
+              s.clear();
               rc = 0;
             }
-            free(buf);
+          }
+          catch (const std::exception & ex) {
+            Syslog(LOG_ERR, "Exception: %s", ex.what());
+            s.clear();
+            rc = 0;
+          }
+          catch (...) {
+            Syslog(LOG_ERR, "Exception");
+            s.clear();
+            rc = 0;
           }
         }
       }
@@ -1178,7 +1199,7 @@ namespace Dwm {
           totalBytesRead = bytesRead;
           break;
         }
-        else if (bytesRead < 0) {
+        else if (bytesRead <= 0) {
           break;
         }
         else {
