@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name$
-// @(#) $Id: DwmIpv4Address.cc 8388 2016-04-17 03:23:45Z dwm $
+// @(#) $Id: DwmIpv4Address.cc 10784 2020-05-15 21:49:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2004-2007
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 //  #define INADDR_NONE  0xffffffff
 #endif
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/src/DwmIpv4Address.cc 8388 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.19/src/DwmIpv4Address.cc 10784 $");
 
 namespace Dwm {
 
@@ -78,7 +78,9 @@ namespace Dwm {
   {
     struct in_addr  inAddr;
     inAddr.s_addr = _addr;
-    return(inet_ntoa(inAddr));
+    char  buf[16] = { '\0' };
+    inet_ntop(AF_INET, &inAddr, buf, 16);
+    return(buf);
   }
 
   //--------------------------------------------------------------------------
