@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.16/tests/TestDwmFileLogger.cc 10165 $
-// @(#) $Id: TestDwmFileLogger.cc 10165 2018-07-22 23:23:33Z dwm $
+// @(#) $DwmPath: dwm/libDwm/tags/libDwm-0.6.19/tests/TestDwmFileLogger.cc 10863 $
+// @(#) $Id: TestDwmFileLogger.cc 10863 2020-07-27 08:54:08Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -39,6 +39,7 @@
 //!  \brief Dwm::FileLogger unit tests
 //---------------------------------------------------------------------------
 
+#include <filesystem>
 #include <fstream>
 #include <regex>
 #include <set>
@@ -82,11 +83,11 @@ static vector<int>  g_priorities = {
 static bool GetLogFiles(FileLogger & logger, set<string> & logFiles)
 {
   logFiles.clear();
-  string  filePrefix(logger.FilePrefix());
-  const char  *dirName = dirname((char *)filePrefix.c_str());
-  DIR *cd = opendir(dirName);
+  std::filesystem::path  filePrefix(logger.FilePrefix());
+  std::string            dirName(filePrefix.parent_path().string());
+  DIR *cd = opendir(dirName.c_str());
   if (cd) {
-    std::regex   logrgx(string(basename((char *)filePrefix.c_str())) + ".*",
+    std::regex   logrgx(filePrefix.filename().string() + ".*",
                         regex::ECMAScript|regex::optimize);
     struct dirent  *de;
     while ((de = readdir(cd))) {
